IconData

Type Alias IconData 

pub type IconData = &'static IconWeightData;
A convenient alias for passing around references to IconWeightData.

While IconWeightData is Copy, it’s not particularly beneficial to pass all those bytes around (48 bytes on WASM, 96 bytes on 64 bit systems).